@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2004 Zope Corporation and Contributors.
+# Copyright (c) 2004 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -13,7 +13,7 @@
 ##############################################################################
 """`APIdoc` skin.
 
-$Id: skin.py 70826 2006-10-20 03:41:16Z baijum $
+$Id: skin.py 113308 2010-06-10 01:09:36Z srichter $
 """
 __docformat__ = "reStructuredText"
 
@@ -25,10 +25,3 @@ class apidoc(IBrowserRequest):
 
 class APIDOC(apidoc, IDefaultBrowserLayer):
     """The `APIDOC` skin."""
-
-# BBB 2006/02/18, to be removed after 12 months
-try:
-    import zope.app.skins
-    zope.app.skins.set('APIDOC', APIDOC)
-except ImportError:
-    pass
